@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
-our $DATE = '2015-07-27'; # DATE
-our $VERSION = '0.20'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.21'; # VERSION
 
 use strict;
 use warnings;
@@ -60,7 +60,7 @@ sub _system_or_backtick {
         }
     }
 
-    $log ||= do { require Log::Any; Log::Any->get_logger } if $opts->{log};
+    $log ||= do { require Log::Any::IfLOG; Log::Any::IfLOG->get_logger } if $opts->{log};
 
     my $wa;
     my $res;
@@ -220,7 +220,7 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.20 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-07-27.
+This document describes version 0.21 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
